pub struct FileEntity {
pub path: String,
}Expand description
A file-level entity (for file-scoped rankings).
Fields
path: StringTrait Implementations
Sourceimpl Clone for FileEntity
impl Clone for FileEntity
Sourcefn clone(&self) -> FileEntity
fn clone(&self) -> FileEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileEntity
impl Debug for FileEntity
Sourceimpl Entity for FileEntity
impl Entity for FileEntity
Sourceimpl JsonSchema for FileEntity
impl JsonSchema for FileEntity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileEntity
impl RefUnwindSafe for FileEntity
impl Send for FileEntity
impl Sync for FileEntity
impl Unpin for FileEntity
impl UnsafeUnpin for FileEntity
impl UnwindSafe for FileEntity