pub struct FunctionEntity {
pub name: String,
pub parent: Option<String>,
pub file_path: String,
pub start_line: usize,
pub end_line: usize,
}Expand description
A function-level entity (for complexity, length, etc.).
Fields
name: Stringparent: Option<String>file_path: Stringstart_line: usizeend_line: usizeTrait Implementations
Sourceimpl Clone for FunctionEntity
impl Clone for FunctionEntity
Sourcefn clone(&self) -> FunctionEntity
fn clone(&self) -> FunctionEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionEntity
impl Debug for FunctionEntity
Sourceimpl Entity for FunctionEntity
impl Entity for FunctionEntity
Sourceimpl JsonSchema for FunctionEntity
impl JsonSchema for FunctionEntity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FunctionEntity
impl RefUnwindSafe for FunctionEntity
impl Send for FunctionEntity
impl Sync for FunctionEntity
impl Unpin for FunctionEntity
impl UnsafeUnpin for FunctionEntity
impl UnwindSafe for FunctionEntity