pub struct ModuleEntity {
pub path: String,
}Expand description
A module-level entity (for density, health, etc.).
Fields
path: StringTrait Implementations
Sourceimpl Clone for ModuleEntity
impl Clone for ModuleEntity
Sourcefn clone(&self) -> ModuleEntity
fn clone(&self) -> ModuleEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleEntity
impl Debug for ModuleEntity
Sourceimpl Entity for ModuleEntity
impl Entity for ModuleEntity
Sourceimpl JsonSchema for ModuleEntity
impl JsonSchema for ModuleEntity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModuleEntity
impl RefUnwindSafe for ModuleEntity
impl Send for ModuleEntity
impl Sync for ModuleEntity
impl Unpin for ModuleEntity
impl UnsafeUnpin for ModuleEntity
impl UnwindSafe for ModuleEntity