pub trait RankEntry {
// Required methods
fn columns() -> Vec<Column>;
fn values(&self) -> Vec<String>;
}Expand description
Trait for entries that can be rendered in a ranked table.
Implement this on your entry struct to use format_ranked_table.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.